==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/opus/translations/opus_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="49"/>
        <source>Opus Plugin</source>
        <translation>Опус прикључак</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="52"/>
        <source>Ogg Opus Files</source>
        <translation>Огг Опус фајлови</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>About Opus Audio Plugin</source>
        <translation>О Опус прикључку</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Кумп Опус прикључак</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Дужина</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Узорковање</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Канала</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Битски проток</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/opus/translations/opus_plugin_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_RS">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="44"/>
        <source>Opus Plugin</source>
        <translation>Опус прикључак</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Ogg Opus Files</source>
        <translation>Огг Опус фајлови</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="121"/>
        <source>About Opus Audio Plugin</source>
        <translation>О Опус прикључку</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>Кумп Опус прикључак</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>Дужина</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>Узорковање</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>Канала</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>Битски проток</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
